==> spt_factory-0.0.8.tar.gz: spt_factory-0.0.8/spt_factory/datascience/pipelines/base_pipeline.py <==
from abc import ABC, abstractmethod


class PipelineConfig:

    def __init__(self, pipeline_name, pipeline_id, config, pipeline_package, pipeline_class):
        self.pipeline_name = pipeline_name
        self.pipeline_id = pipeline_id
        self.config = config
        self.pipeline_package = pipeline_package
        self.pipeline_class = pipeline_class

    def to_dict(self):
        return {
            'pipeline_name': self.pipeline_name,
            'pipeline_id': self.pipeline_id,
            'config': self.config,
            'pipeline_package': self.pipeline_package,
            'pipeline_class': self.pipeline_class
        }

    @staticmethod
    def from_dict(config_dict: dict):
        return PipelineConfig(
            pipeline_name=config_dict['pipeline_name'],
            pipeline_id=config_dict['pipeline_id'],
            config=config_dict['config'],
            pipeline_package=config_dict['pipeline_package'],
            pipeline_class=config_dict['pipeline_class'],
        )


class BasePipeline(ABC):

    @abstractmethod
    def save_pipeline(self, pipeline_id) -> PipelineConfig:
        """
        trigger inside models to saving
        :return: config dict
        """
        pass

    @staticmethod
    @abstractmethod
    def load_pipeline(config, model_manager):
        """
        :param pipeline_id:
        :return:
        """
        pass

    @abstractmethod
    def pipeline_name(self) -> str:
        """
        :return: pipelines name
        """
        pass

    @abstractmethod
    def predict(self, features):
        pass

    @abstractmethod
    def predict_proba(self, features):
        pass

    @abstractmethod
    def pipeline_score(self):
        pass

==> spt_factory-0.0.14.tar.gz: spt_factory-0.0.14/spt_factory/datascience/pipelines/base_pipeline.py <==
from abc import ABC, abstractmethod


class PipelineConfig:

    def __init__(self, pipeline_name, pipeline_id, config, pipeline_package, pipeline_class, target_problem):
        self.pipeline_name = pipeline_name
        self.pipeline_id = pipeline_id
        self.config = config
        self.pipeline_package = pipeline_package
        self.pipeline_class = pipeline_class
        self.target_problem = target_problem

    def to_dict(self):
        return {
            'pipeline_name': self.pipeline_name,
            'pipeline_id': self.pipeline_id,
            'config': self.config,
            'pipeline_package': self.pipeline_package,
            'pipeline_class': self.pipeline_class,
            'target_problem': self.target_problem
        }

    @staticmethod
    def from_dict(config_dict: dict):
        return PipelineConfig(
            pipeline_name=config_dict['pipeline_name'],
            pipeline_id=config_dict['pipeline_id'],
            config=config_dict['config'],
            pipeline_package=config_dict['pipeline_package'],
            pipeline_class=config_dict['pipeline_class'],
            target_problem=config_dict['target_problem']
        )


class BasePipeline(ABC):

    @abstractmethod
    def save_pipeline(self, pipeline_id) -> PipelineConfig:
        """
        trigger inside models to saving
        :return: config dict
        """
        pass

    @staticmethod
    @abstractmethod
    def load_pipeline(config, model_manager):
        """
        :param pipeline_id:
        :return:
        """
        pass

    @abstractmethod
    def pipeline_name(self) -> str:
        """
        :return: pipelines name
        """
        pass

    @abstractmethod
    def predict(self, features):
        pass

    @abstractmethod
    def predict_proba(self, features):
        pass

    @abstractmethod
    def pipeline_score(self):
        pass
